;ASDesign Compatible Macro
;Name=Trees Lib: Line of 10 - 1 type, Type=Trees \
;FixedLength=90, FixedWidth=2, Autoscale, \
;Latitude, Longitude, Range=8, Scale=1, Rotation=0, \
;Visibility=25000, Elevation=0, Density=4, \
;Hemisphere=0, Lat_Band=2, Tree_ID=00001, Tree_Scale=1.0
; *******************************************************************
; TrLn10_1.scm  Trees: Straight line of 10 trees of 1 type
; -------------------------------------------------------------------
; Author:	      Gerrish Gray, Freeware - All Rights Reserved
; Contact:      gerrish.gray@wimborne-dorset.fsnet.co.uk
; Use With:     FS2000 and ASD 2.1
; Needs:        Trees_#.bgl libraries (must be Release 2)
; ===================================================================
; NOTES:
; 1. This macro creates a straight line of evenly-spaced trees.  It
;    is suitable for avenues, hedges, etc.
; 2. Tree line 'radiates' from initial position at one end of line.
;    Use Rotation parameter to set direction (0 = North).
; 3. Use Scale to set tree-tree spacing (1.0 = 10m).  When creating
;    hedges, this spacing should be somewhat less than the diameter
;    of the individual shrubs to create a continuous hedge viewed
;    from all angles.
; 4. Use Hemisphere and Latitude Band settings to select appropriate
;    seasonal behaviour corresponding to the location and altitude of
;    the scenery.  Hemisphere is 0 for Northern or 1 for Southern.
;    Latitude Band values range from 1 (tropical) to 4 (sub-arctic).
; 5. Use Tree ID to select tree type - see Trees_#.txt
;    *IMPORTANT* Not all tree types are available in all Bands. It is
;    the scenery designer's responsibility to select appropriate tree
;    types for the band in use, as detailed in the Trees_#.txt files.
;    Misuse will lead to 'Missing Object ...' error messages when 
;    opening the scenery in Flight Simulator.
; 6. Use Tree Scale to set tree size independently of line scale
; 7. Size of individual trees is adjusted slightly by macro to ensure
;    a 'natural' appearance with no two trees exactly the same size
; 8. Leave Altitude setting at zero to allow trees to stand correctly
;    on FS2000 elevated mesh terrain and follow terrain contours
; 9. Scenery Detail setting determines level at which ALL trees are
;    drawn. Fewer trees are drawn at lower settings, and NO trees
;    will ever be drawn when the FS2000 setting is Very Sparse
; -------------------------------------------------------------------
; PARAMETERS:
; %1  = Latitude  - Latitude & Longitude set starting point of line
; %2  = Longitude                               ... see note 1 above          
; %3  = Area() range in kms
; %4  = Scale - sets tree spacing, 1.0 = 10m. Does NOT set tree size
; %5  = Rotation - sets orientation (direction) of line (0=North)
; %6  = Visibility range in metres
; %7  = Altitude - normally leave at 0 for local ground level
; %8  = Scenery Detail level - see note 9 above
; %9  = Argument 1 - Hemisphere (0=North 1=South),
; %10 = Argument 2 - Latitude Band (1-4)
; %11 = Argument 3 - Tree ID (must be a valid ID)
; %12 = Argument 4 - Tree Scale (sets size of trees)
; ===================================================================
; RELEASE HISTORY
; ---------------
; 2000-12-16    Release 2
;               - Uses Release 2 libraries (modified object coding
;                 & GUIDs)
;               - Adds SCM macros to SDK
; 2000-12-10    Release 1 - SCM macros not included
; *******************************************************************

; CONSTANTS
; =========

; FS2000 global variables
; -----------------------
  UVar( $detail  0x0346 ) ; scenery detail level

; Calculate ID increments from band parameters
; --------------------------------------------
mif( %9 )
  UVar( $hemi 5 )
melse
  UVar( $hemi 0 )
mifend

mif( [ abs[%10] > 4 ] )
  Error( The Latitude Band parameter must be in the range 1 to 4 )
mifend

mif( [ abs[%10] > 1 ] )
  UVar( $band abs[ int[%10] ] )
melse
  UVar( $band  1 )
mifend

; Tree ID's & Scales
; ------------------
  UVar( $ID1  [[0x0%11*16]+$hemi+$band] )
  UVar( $z1   %12 )

; BGL CODE
; ========

Area( 5 %1 %2 %3 )
  IfVarRange( : $detail 1 5 )
  PerspectiveCall( :Persp )
  Jump( : )

; --------------
; TREE PATTERN:
; No scale det
; -- ----- ---
; 00  1.0  -3
; 01  1.03  0
; 02  0.94 -2
; 03  0.97  0
; 04  1.06 -1
; 05  0.97  0
; 06  1.0  -3
; 07  1.03  0
; 08  0.94 -2
; 09  1.06 -1
; --------------

:Persp
  Perspective

:tree00
mif( %7  )
  RefPoint( 2 :tree01 %4 %1 %2 v1= %6 E= %7 V2= 50 )
melse
  RefPoint( 7 :tree01 %4 %1 %2 v1= %6 V2= 50 )
mifend
  SetScale( :tree01 0 0 $z1 )
  CallLibObj( 0 $ID1 326C6552 45455254 42494C53 )

:tree01
  IfVarRange( :tree02 $detail %8 5 )
mif( %7  )
  RefPoint( 2 :tree02 %4 r %5 10*%4 )
melse
  RefPoint( 7 :tree02 %4 r %5 10*%4 )
mifend
  SetScale( :tree02 0 0 $z1*1.03 )
  CallLibObj( 0 $ID1 326C6552 45455254 42494C53 )

:tree02
  IfVarRange( :tree03 $detail %8-2 5 )
mif( %7  )
  RefPoint( 2 :tree03 %4 r %5 20*%4 )
melse
  RefPoint( 7 :tree03 %4 r %5 20*%4 )
mifend
  SetScale( :tree03 0 0 $z1*0.94 )
  CallLibObj( 0 $ID1 326C6552 45455254 42494C53 )

:tree03
  IfVarRange( :tree04 $detail %8 5 )
mif( %7  )
  RefPoint( 2 :tree04 %4 r %5 30*%4 )
melse
  RefPoint( 7 :tree04 %4 r %5 30*%4 )
mifend
  SetScale( :tree04 0 0 $z1*0.97 )
  CallLibObj( 0 $ID1 326C6552 45455254 42494C53 )

:tree04
  IfVarRange( :tree05 $detail %8-1 5 )
mif( %7  )
  RefPoint( 2 :tree05 %4 r %5 40*%4 )
melse
  RefPoint( 7 :tree05 %4 r %5 40*%4 )
mifend
  SetScale( :tree05 0 0 $z1*1.06 )
  CallLibObj( 0 $ID1 326C6552 45455254 42494C53 )

:tree05
  IfVarRange( :tree06 $detail %8 5 )
mif( %7  )
  RefPoint( 2 :tree06 %4 r %5 50*%4 )
melse
  RefPoint( 7 :tree06 %4 r %5 50*%4 )
mifend
  SetScale( :tree06 0 0 $z1*0.97 )
  CallLibObj( 0 $ID1 326C6552 45455254 42494C53 )

:tree06
mif( %7  )
  RefPoint( 2 :tree07 %4 r %5 60*%4 )
melse
  RefPoint( 7 :tree07 %4 r %5 60*%4 )
mifend
  SetScale( :tree07 0 0 $z1 )
  CallLibObj( 0 $ID1 326C6552 45455254 42494C53 )

:tree07
  IfVarRange( :tree08 $detail %8 5 )
mif( %7  )
  RefPoint( 2 :tree08 %4 r %5 70*%4 )
melse
  RefPoint( 7 :tree08 %4 r %5 70*%4 )
mifend
  SetScale( :tree08 0 0 $z1*1.03 )
  CallLibObj( 0 $ID1 326C6552 45455254 42494C53 )

:tree08
  IfVarRange( :tree09 $detail %8-2 5 )
mif( %7  )
  RefPoint( 2 :tree09 %4 r %5 80*%4 )
melse
  RefPoint( 7 :tree09 %4 r %5 80*%4 )
mifend
  SetScale( :tree09 0 0 $z1*0.94 )
  CallLibObj( 0 $ID1 326C6552 45455254 42494C53 )

:tree09
  IfVarRange( :EndP $detail %8-1 5 )
mif( %7  )
  RefPoint( 2 :EndP %4 r %5 90*%4 )
melse
  RefPoint( 7 :EndP %4 r %5 90*%4 )
mifend
  SetScale( :EndP 0 0 $z1*1.06 )
  CallLibObj( 0 $ID1 326C6552 45455254 42494C53 )

:EndP
  Return
EndA

