;ASDesign Compatible Macro
;Name=Trees Lib: 5x5 square - 4 types, Type=Trees \
;FixedLength=40, FixedWidth=40, Autoscale, \
;Latitude, Longitude, Range=8, Scale=1, Rotation=0, \
;Visibility=25000, Elevation=0, Density=4, \
;Hemisphere=0, Lat_Band=2, Tree_ID_1=00001, Scale_1=1.0, \
;Tree_ID_2=00002, Scale_2=1.0, Tree_ID_3=00003, Scale_3=1.0, \
;Tree_ID_4=00004, Scale_4=1.0
; *******************************************************************
; TrSq5_4.scm   Trees: Regular 5 x 5 square of trees of 4 mixed types
; -------------------------------------------------------------------
; Author:	      Gerrish Gray, Freeware - All Rights Reserved
; Contact:      gerrish.gray@wimborne-dorset.fsnet.co.uk
; Use With:     FS2000 and ASD 2.1
; Needs:        Trees_#.bgl libraries (must be Release 2)
; ===================================================================
; NOTES:
; 1. This macro creates a square grid of trees suitable for a 
;    cultivated plantation.  The trees are 'planted' in straight
;    lines with even spacing.  This macro is NOT particularly
;    suitable for use with the '3D Group' tree variants as the 
;    appearance of the resulting plantation will not be natural.
; 2. Initial position gives bottom left 'origin' of square (NOT 
;    centre point).  Use Rotation parameter to set orientation
;    (0 = long side runs due North, short side due East).
; 3. Use Scale to set row-row/tree-tree spacing (1.0 = 10m).  This
;    setting does NOT control the size of the trees (see note 6).
; 4. Use Hemisphere and Latitude Band settings to select appropriate
;    seasonal behaviour corresponding to the location and altitude of
;    the scenery.  Hemisphere is 0 for Northern or 1 for Southern.
;    Latitude Band values range from 1 (tropical) to 4 (sub-arctic).
; 5. Use Tree ID's to select tree types - see Trees_#.txt
;    *IMPORTANT* Not all tree types are available in all Bands. It is
;    the scenery designer's responsibility to select appropriate tree
;    types for the band in use, as detailed in the Trees_#.txt files.
;    Misuse will lead to 'Missing Object ...' error messages when 
;    opening the scenery in Flight Simulator.
; 6. Use Tree Scales to set tree sizes independently of grid spacing
; 7. Size of individual trees is adjusted slightly by macro to ensure
;    a 'natural' appearance with no two trees exactly the same size.
; 8. Leave Altitude setting at zero to allow trees to stand correctly
;    on FS2000 elevated mesh terrain and follow even the steepest
;    terrain contours. (Note, however, that 3D Groups will not work
;    so well on steeper slopes).
; 9. Scenery Detail setting determines level at which ALL trees are
;    drawn. Fewer trees are drawn at lower settings, and NO trees
;    will ever be drawn when the FS2000 setting is Very Sparse
; -------------------------------------------------------------------
; PARAMETERS:
; %1  = Latitude  - Sets 'origin' of square, see note 1 above          
; %2  = Longitude      ..   ..   ..
; %3  = Area() range in kms
; %4  = Scale - sets tree spacing, 1.0 = 10m. Does NOT set tree size
; %5  = Rotation - sets orientation of square - see note 2 above
; %9  = Argument 1 - Hemisphere (0=North 1=South),
; %6  = Visibility range in metres
; %7  = Altitude - normally leave at 0 for local ground level
; %8  = Scenery Detail level - see note 9 above
; %10 = Argument 2 - Latitude Band (1-4)
; %11 = Argument 3 - Tree ID for type 1
; %12 = Argument 4 - Tree Scale for type 1
; %13 = Argument 5 - Tree ID for type 2
; %14 = Argument 6 - Tree Scale for type 2
; %15 = Argument 7 - Tree ID for type 3
; %16 = Argument 8 - Tree Scale for type 3
; %17 = Argument 9 - Tree ID for type 4
; %18 = Argument 10 - Tree Scale for type 4
; ===================================================================
; RELEASE HISTORY
; ---------------
; 2000-12-16    Release 2
;               - Uses Release 2 libraries (modified object coding
;                 & GUIDs)
;               - Adds SCM macros to SDK
; 2000-12-10    Release 1 - SCM macros not included
; *******************************************************************

; CONSTANTS
; =========

; FS2000 global variables
; -----------------------
  UVar( $detail  0x0346 ) ; scenery detail level

; Calculate ID increments from band parameters
; --------------------------------------------
mif( %9 )
  UVar( $hemi 5 )
melse
  UVar( $hemi 0 )
mifend

mif( [ abs[%10] > 4 ] )
  Error( The Latitude Band parameter must be in the range 1 to 4 )
mifend

mif( [ abs[%10] > 1 ] )
  UVar( $band abs[int[%10]] )
melse
  UVar( $band 1 )
mifend

; Tree ID's & Scales
; ------------------
  UVar( $ID1  [[0x0%11*16]+$hemi+$band] )
  UVar( $z1   %12 )
  UVar( $ID2  [[0x0%13*16]+$hemi+$band] )
  UVar( $z2   %14 )
  UVar( $ID3  [[0x0%15*16]+$hemi+$band] )
  UVar( $z3   %16 )
  UVar( $ID4  [[0x0%17*16]+$hemi+$band] )
  UVar( $z4   %18 )

; BGL CODE
; ========

Area( 5 %1 %2 %3 )
  IfVarRange( : $detail 1 5 )
  PerspectiveCall( :Persp )
  Jump( : )

; -------------------------------------------------------------------
; TREE PATTERN:
; No t scal dt|No t scal dt|No t scal dt|No t scal dt|No t scal dt
; -- - ---- --|-- - ---- --|-- - ---- --|-- - ---- --|-- - ---- --
; 00 1 1.0  -3|10 4 0.94  0|20 4 1.03 -1|30 2 0.94  0|40 3 0.97 -2
; 01 2 1.03  0|11 3 1.06 -1|21 2 0.94  0|31 2 1.0  -1|41 1 1.06  0
; 02 3 0.94 -2|12 1 0.97  0|22 1 1.06 -3|32 3 0.97  0|42 1 1.0  -1
; 03 4 0.97  0|13 3 1.03 -3|23 4 1.0   0|33 1 1.06 -2|43 2 1.03  0
; 04 2 1.06 -1|14 1 1.0   0|24 3 0.97 -2|34 4 1.03  0|44 4 0.94 -3
; -------------------------------------------------------------------

:Persp
  Perspective

:tree00
mif( %7  )
  RefPoint( 2 :tree01 %4 %1 %2 v1= %6 E= %7 V2= 50 )
melse
  RefPoint( 7 :tree01 %4 %1 %2 v1= %6 V2= 50 )
mifend
  SetScale( :tree01 0 0 $z1 )
  CallLibObj( 0 $ID1 326C6552 45455254 42494C53 )

:tree01
  IfVarRange( :tree02 $detail %8 5 )
mif( %7  )
  RefPoint( 2 :tree02 %4 r %5 10*%4 )
melse
  RefPoint( 7 :tree02 %4 r %5 10*%4 )
mifend
  SetScale( :tree02 0 0 $z2*1.03 )
  CallLibObj( 0 $ID2 326C6552 45455254 42494C53 )

:tree02
  IfVarRange( :tree03 $detail %8-2 5 )
mif( %7  )
  RefPoint( 2 :tree03 %4 r %5 20*%4 )
melse
  RefPoint( 7 :tree03 %4 r %5 20*%4 )
mifend
  SetScale( :tree03 0 0 $z3*0.94 )
  CallLibObj( 0 $ID3 326C6552 45455254 42494C53 )

:tree03
  IfVarRange( :tree04 $detail %8 5 )
mif( %7  )
  RefPoint( 2 :tree04 %4 r %5 30*%4 )
melse
  RefPoint( 7 :tree04 %4 r %5 30*%4 )
mifend
  SetScale( :tree04 0 0 $z4*0.97 )
  CallLibObj( 0 $ID4 326C6552 45455254 42494C53 )

:tree04
  IfVarRange( :tree10 $detail %8-1 5 )
mif( %7  )
  RefPoint( 2 :tree10 %4 r %5 40*%4 )
melse
  RefPoint( 7 :tree10 %4 r %5 40*%4 )
mifend
  SetScale( :tree10 0 0 $z2*1.06 )
  CallLibObj( 0 $ID2 326C6552 45455254 42494C53 )

; Row 1
; -----

:tree10
  GRP( r %5+90 10*%4 )
  IfVarRange( :tree11 $detail %8 5 )
mif( %7  )
  RefPoint( 2 :tree11 %4 r %5 0 )
melse
  RefPoint( 7 :tree11 %4 r %5 0 )
mifend
  SetScale( :tree11 0 0 $z4*0.94 )
  CallLibObj( 0 $ID4 326C6552 45455254 42494C53 )

:tree11
  IfVarRange( :tree12 $detail %8-1 5 )
mif( %7  )
  RefPoint( 2 :tree12 %4 r %5 10*%4 )
melse
  RefPoint( 7 :tree12 %4 r %5 10*%4 )
mifend
  SetScale( :tree12 0 0 $z3*1.06 )
  CallLibObj( 0 $ID3 326C6552 45455254 42494C53 )

:tree12
  IfVarRange( :tree13 $detail %8 5 )
mif( %7  )
  RefPoint( 2 :tree13 %4 r %5 20*%4 )
melse
  RefPoint( 7 :tree13 %4 r %5 20*%4 )
mifend
  SetScale( :tree13 0 0 $z1*0.97 )
  CallLibObj( 0 $ID1 326C6552 45455254 42494C53 )

:tree13
  IfVarRange( :tree14 $detail %8-3 5 )
mif( %7  )
  RefPoint( 2 :tree14 %4 r %5 30*%4 )
melse
  RefPoint( 7 :tree14 %4 r %5 30*%4 )
mifend
  SetScale( :tree14 0 0 $z3*1.03 )
  CallLibObj( 0 $ID3 326C6552 45455254 42494C53 )

:tree14
  IfVarRange( :tree20 $detail %8 5 )
mif( %7  )
  RefPoint( 2 :tree20 %4 r %5 40*%4 )
melse
  RefPoint( 7 :tree20 %4 r %5 40*%4 )
mifend
  SetScale( :tree20 0 0 $z1 )
  CallLibObj( 0 $ID1 326C6552 45455254 42494C53 )

; Row 2
; -----

:tree20
  GRP( r %5+90 10*%4 )
  IfVarRange( :tree21 $detail %8-1 5 )
mif( %7  )
  RefPoint( 2 :tree21 %4 r %5 0 )
melse
  RefPoint( 7 :tree21 %4 r %5 0 )
mifend
  SetScale( :tree21 0 0 $z4*1.03 )
  CallLibObj( 0 $ID4 326C6552 45455254 42494C53 )

:tree21
  IfVarRange( :tree22 $detail %8 5 )
mif( %7  )
  RefPoint( 2 :tree22 %4 r %5 10*%4 )
melse
  RefPoint( 7 :tree22 %4 r %5 10*%4 )
mifend
  SetScale( :tree22 0 0 $z2*0.94 )
  CallLibObj( 0 $ID2 326C6552 45455254 42494C53 )

:tree22
mif( %7  )
  RefPoint( 2 :tree23 %4 r %5 20*%4 )
melse
  RefPoint( 7 :tree23 %4 r %5 20*%4 )
mifend
  SetScale( :tree23 0 0 $z1*1.06 )
  CallLibObj( 0 $ID1 326C6552 45455254 42494C53 )

:tree23
  IfVarRange( :tree24 $detail %8 5 )
mif( %7  )
  RefPoint( 2 :tree24 %4 r %5 30*%4 )
melse
  RefPoint( 7 :tree24 %4 r %5 30*%4 )
mifend
  SetScale( :tree24 0 0 $z4 )
  CallLibObj( 0 $ID4 326C6552 45455254 42494C53 )

:tree24
  IfVarRange( :tree30 $detail %8-2 5 )
mif( %7  )
  RefPoint( 2 :tree30 %4 r %5 40*%4 )
melse
  RefPoint( 7 :tree30 %4 r %5 40*%4 )
mifend
  SetScale( :tree30 0 0 $z3*0.97 )
  CallLibObj( 0 $ID3 326C6552 45455254 42494C53 )

; Row 3
; -----

:tree30
  GRP( r %5+90 10*%4 )
  IfVarRange( :tree31 $detail %8 5 )
mif( %7  )
  RefPoint( 2 :tree31 %4 r %5 0 )
melse
  RefPoint( 7 :tree31 %4 r %5 0 )
mifend
  SetScale( :tree31 0 0 $z2*0.94 )
  CallLibObj( 0 $ID2 326C6552 45455254 42494C53 )

:tree31
  IfVarRange( :tree32 $detail %8-1 5 )
mif( %7  )
  RefPoint( 2 :tree32 %4 r %5 10*%4 )
melse
  RefPoint( 7 :tree32 %4 r %5 10*%4 )
mifend
  SetScale( :tree32 0 0 $z2 )
  CallLibObj( 0 $ID2 326C6552 45455254 42494C53 )

:tree32
  IfVarRange( :tree33 $detail %8 5 )
mif( %7  )
  RefPoint( 2 :tree33 %4 r %5 20*%4 )
melse
  RefPoint( 7 :tree33 %4 r %5 20*%4 )
mifend
  SetScale( :tree33 0 0 $z3*0.97 )
  CallLibObj( 0 $ID3 326C6552 45455254 42494C53 )

:tree33
  IfVarRange( :tree34 $detail %8-2 5 )
mif( %7  )
  RefPoint( 2 :tree34 %4 r %5 30*%4 )
melse
  RefPoint( 7 :tree34 %4 r %5 30*%4 )
mifend
  SetScale( :tree34 0 0 $z1*1.06 )
  CallLibObj( 0 $ID1 326C6552 45455254 42494C53 )

:tree34
  IfVarRange( :tree40 $detail %8 5 )
mif( %7  )
  RefPoint( 2 :tree40 %4 r %5 40*%4 )
melse
  RefPoint( 7 :tree40 %4 r %5 40*%4 )
mifend
  SetScale( :tree40 0 0 $z4*1.03 )
  CallLibObj( 0 $ID4 326C6552 45455254 42494C53 )

; Row 4
; -----

:tree40
  GRP( r %5+90 10*%4 )
  IfVarRange( :tree41 $detail %8-2 5 )
mif( %7  )
  RefPoint( 2 :tree41 %4 r %5 0 )
melse
  RefPoint( 7 :tree41 %4 r %5 0 )
mifend
  SetScale( :tree41 0 0 $z3*0.97 )
  CallLibObj( 0 $ID3 326C6552 45455254 42494C53 )

:tree41
  IfVarRange( :tree42 $detail %8 5 )
mif( %7  )
  RefPoint( 2 :tree42 %4 r %5 10*%4 )
melse
  RefPoint( 7 :tree42 %4 r %5 10*%4 )
mifend
  SetScale( :tree42 0 0 $z1*1.06 )
  CallLibObj( 0 $ID1 326C6552 45455254 42494C53 )

:tree42
  IfVarRange( :tree43 $detail %8-1 5 )
mif( %7  )
  RefPoint( 2 :tree43 %4 r %5 20*%4 )
melse
  RefPoint( 7 :tree43 %4 r %5 20*%4 )
mifend
  SetScale( :tree43 0 0 $z1 )
  CallLibObj( 0 $ID1 326C6552 45455254 42494C53 )

:tree43
  IfVarRange( :tree44 $detail %8 5 )
mif( %7  )
  RefPoint( 2 :tree44 %4 r %5 30*%4 )
melse
  RefPoint( 7 :tree44 %4 r %5 30*%4 )
mifend
  SetScale( :tree44 0 0 $z2*1.03 )
  CallLibObj( 0 $ID2 326C6552 45455254 42494C53 )

:tree44
mif( %7  )
  RefPoint( 2 :EndP %4 r %5 40*%4 )
melse
  RefPoint( 7 :EndP %4 r %5 40*%4 )
mifend
  SetScale( :EndP 0 0 $z4*0.94 )
  CallLibObj( 0 $ID4 326C6552 45455254 42494C53 )

:EndP
  Return
EndA
