;ASDesign Compatible Macro
;Name=Trees Lib: Stand of 7 - 3 types, Type=Trees \
;FixedLength=16, FixedWidth=23, Autoscale, \
;Latitude, Longitude, Range=8, Scale=1, Rotation=0, \
;Visibility=25000, Elevation=0, Density=4, \
;Hemisphere=0, Lat_Band=2, Tree_ID_1=00001, Scale_1=1.0, \
;Tree_ID_2=00002, Scale_2=1.0, Tree_ID_3=00003, Scale_3=1.0 
; *******************************************************************
; TrSt7_3.scm   Trees: Irregular stand of 7 trees of 3 mixed types
; -------------------------------------------------------------------
; Author:	      Gerrish Gray, Freeware - All Rights Reserved
; Contact:      gerrish.gray@wimborne-dorset.fsnet.co.uk
; Use With:     FS2000 and ASD 2.1
; Needs:        Trees_#.bgl libraries (must be Release 2)
; ===================================================================
; NOTES:
; 1. This macro creates an irregularly-shaped stand of 7 trees of
;    somewhat varying size.  Very natural in appearance.
; 2. Reference point gives position of central tree of group.  
;    Rotation parameter sets orientation.
; 3. Use Scale to set average centre-to-centre spacing (1.0 = 10m).
; 4. Use Hemisphere and Latitude Band settings to select appropriate
;    seasonal behaviour corresponding to the location and altitude of
;    the scenery.  Hemisphere is 0 for Northern or 1 for Southern.
;    Latitude Band values range from 1 (tropical) to 4 (sub-arctic).
; 5. Use Tree ID to select tree type - see Trees_#.txt
;    *IMPORTANT* Not all tree types are available in all Bands. It is
;    the scenery designer's responsibility to select appropriate tree
;    types for the band in use, as detailed in the Trees_#.txt files.
;    Misuse will lead to 'Missing Object ...' error messages when 
;    opening the scenery in Flight Simulator.
; 6. Use Tree Scale to set average tree size independently of main
;    scale.
; 7. Size of individual trees is adjusted by macro to ensure a
;    natural appearance with no two trees exactly the same size
; 8. Leave Altitude setting at zero to allow trees to stand correctly
;    on FS2000 elevated mesh terrain and follow even the steepest
;    terrain contours. (Note, however, that 3D Groups will not work
;    so well on steeper slopes).
; 9. Scenery Detail setting determines level at which ALL trees are
;    drawn. Fewer trees are drawn at lower settings, and NO trees
;    will ever be drawn when the FS2000 setting is Very Sparse
; -------------------------------------------------------------------
; PARAMETERS:
; %1  = Latitude  - Sets position of tree at centre of stand
; %2  = Longitude      ..   ..   ..
; %3  = Area() range in kms
; %4  = Scale - sets average tree spacing, 1.0 = 10m; NOT tree size
; %5  = Rotation - sets orientation - see note 2 above
; %6  = Visibility range in metres
; %7  = Altitude - normally leave at 0 for local ground level
; %8  = Scenery Detail level - see note 9 above
; %9  = Argument 1 - Hemisphere (0=North 1=South),
; %10 = Argument 2 - Latitude Band (1-4)
; %11 = Argument 3 - Tree ID for type 1
; %12 = Argument 4 - Tree Scale for type 1
; %13 = Argument 5 - Tree ID for type 2
; %14 = Argument 6 - Tree Scale for type 2
; %15 = Argument 7 - Tree ID for type 3
; %16 = Argument 8 - Tree Scale for type 3
; ===================================================================
; RELEASE HISTORY
; ---------------
; 2000-12-17    Release 2
;               - Uses Release 2 libraries (modified object coding
;                 & GUIDs)
;               - Adds SCM macros to SDK
; 2000-12-10    Release 1 - SCM macros not included
; *******************************************************************

; CONSTANTS
; =========

; FS2000 global variables
; -----------------------
  UVar( $detail  0x0346 ) ; scenery detail level

; Calculate ID increments from band parameters
; --------------------------------------------
mif( %9 )
  UVar( $hemi 5 )
melse
  UVar( $hemi 0 )
mifend

mif( [ abs[%10] > 4 ] )
  Error( The Latitude Band parameter must be in the range 1 to 4 )
mifend

mif( [ abs[%10] > 1 ] )
  UVar( $band abs[int[%10]] )
melse
  UVar( $band 1 )
mifend

; Tree ID's & Scales
; ------------------
  UVar( $ID1  [[0x0%11*16]+$hemi+$band] )
  UVar( $z1   %12 )
  UVar( $ID2  [[0x0%13*16]+$hemi+$band] )
  UVar( $z2   %14 )
  UVar( $ID3  [[0x0%15*16]+$hemi+$band] )
  UVar( $z3   %16 )

; BGL CODE
; ========

Area( 5 %1 %2 %3 )
  IfVarRange( : $detail 1 5 )
  PerspectiveCall( :Persp )
  Jump( : )

; -----------------------
; TREE PATTERN:
; No tp  r   d scale det
; -- -- --- -- ----- ---
; 00  1   0  0  1.15 -3
; 11  3  30  7  1.07  0
; 12  2 100 10  0.85 -2
; 13  1 155  9  0.93  0
; 14  3 210  8  1.0  -1
; 15  2 260 11  1.07  0
; 16  1 320  8  0.93 -1
; -----------------------

:Persp
  Perspective

:tree00
mif( %7  )
  RefPoint( 2 :tree11 %4 %1 %2 v1= %6 E= %7 V2= 50 )
melse
  RefPoint( 7 :tree11 %4 %1 %2 v1= %6 V2= 50 )
mifend
  SetScale( :tree11 0 0 $z1*1.15 )
  CallLibObj( 0 $ID1 326C6552 45455254 42494C53 )

:tree11
  IfVarRange( :tree12 $detail %8 5 )
mif( %7  )
  RefPoint( 2 :tree12 %4 r %5+30 7*%4 )
melse
  RefPoint( 7 :tree12 %4 r %5+30 7*%4 )
mifend
  SetScale( :tree12 0 0 $z3*1.07 )
  CallLibObj( 0 $ID3 326C6552 45455254 42494C53 )

:tree12
  IfVarRange( :tree13 $detail %8-2 5 )
mif( %7  )
  RefPoint( 2 :tree13 %4 r %5+100 10*%4 )
melse
  RefPoint( 7 :tree13 %4 r %5+100 10*%4 )
mifend
  SetScale( :tree13 0 0 $z2*0.85 )
  CallLibObj( 0 $ID2 326C6552 45455254 42494C53 )

:tree13
  IfVarRange( :tree14 $detail %8 5 )
mif( %7  )
  RefPoint( 2 :tree14 %4 r %5+155 9*%4 )
melse
  RefPoint( 7 :tree14 %4 r %5+155 9*%4 )
mifend
  SetScale( :tree14 0 0 $z1*0.93 )
  CallLibObj( 0 $ID1 326C6552 45455254 42494C53 )

:tree14
  IfVarRange( :tree15 $detail %8-1 5 )
mif( %7  )
  RefPoint( 2 :tree15 %4 r %5+210 8*%4 )
melse
  RefPoint( 7 :tree15 %4 r %5+210 8*%4 )
mifend
  SetScale( :tree15 0 0 $z3 )
  CallLibObj( 0 $ID3 326C6552 45455254 42494C53 )

:tree15
  IfVarRange( :tree16 $detail %8 5 )
mif( %7  )
  RefPoint( 2 :tree16 %4 r %5+260 11*%4 )
melse
  RefPoint( 7 :tree16 %4 r %5+260 11*%4 )
mifend
  SetScale( :tree16 0 0 $z2*1.07 )
  CallLibObj( 0 $ID2 326C6552 45455254 42494C53 )

:tree16
  IfVarRange( :EndP $detail %8-1 5 )
mif( %7  )
  RefPoint( 2 :EndP %4 r %5+320 8*%4 )
melse
  RefPoint( 7 :EndP %4 r %5+320 8*%4 )
mifend
  SetScale( :EndP 0 0 $z1*0.93 )
  CallLibObj( 0 $ID1 326C6552 45455254 42494C53 )

:EndP
  Return
EndA
